@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -77,7 +77,7 @@ function add_tree_names_to_actions_array() {
 
 	if (sizeof($trees)) {
 		foreach ($trees as $tree) {
-			$graph_actions{'tr_' . $tree['id']} = __('Place on a Tree (%s)', $tree['name']);
+			$graph_actions['tr_' . $tree['id']] = __('Place on a Tree (%s)', $tree['name']);
 		}
 	}
 }
@@ -100,8 +100,8 @@ function form_save() {
 	}
 
 	/* get the aggregate graph id */
-	$aggregate_graph_id  = db_fetch_cell_prepared('SELECT id 
-		FROM aggregate_graphs 
+	$aggregate_graph_id  = db_fetch_cell_prepared('SELECT id
+		FROM aggregate_graphs
 		WHERE local_graph_id = ?', array($local_graph_id));
 
 	/* if user disabled template propagation we need to get graph data from form */
@@ -128,9 +128,9 @@ function form_save() {
 	);
 
 	/* update title in aggregate graphs table */
-	db_execute_prepared('UPDATE aggregate_graphs 
+	db_execute_prepared('UPDATE aggregate_graphs
 		SET title_format = ?
-		WHERE id = ?', 
+		WHERE id = ?',
 		array($graph_title, $aggregate_graph_id));
 
 	/* next lets see if any of the aggregate has changed and save as applicable
@@ -153,9 +153,9 @@ function form_save() {
 
 		/* see if anything changed, if so, we will have to push out the aggregate */
 		if (!empty($aggregate_graph_id)) {
-			$old = db_fetch_row_prepared('SELECT * 
-				FROM aggregate_graphs 
-				WHERE id = ?', 
+			$old = db_fetch_row_prepared('SELECT *
+				FROM aggregate_graphs
+				WHERE id = ?',
 				array($aggregate_graph_id));
 
 			$save_me = 0;
@@ -176,17 +176,17 @@ function form_save() {
 			/* save the template items now */
 			/* get existing item ids and sequences from graph template */
 			$graph_templates_items = array_rekey(
-				db_fetch_assoc_prepared('SELECT id, sequence 
-					FROM graph_templates_item 
-					WHERE local_graph_id=0 
+				db_fetch_assoc_prepared('SELECT id, sequence
+					FROM graph_templates_item
+					WHERE local_graph_id=0
 					AND graph_template_id = ?
 					ORDER BY sequence', array($graph_template_id)),
 				'id', array('sequence')
 			);
 			/* get existing aggregate template items */
 			$aggregate_graph_items_old = array_rekey(
-				db_fetch_assoc_prepared('SELECT * 
-					FROM aggregate_graphs_graph_item 
+				db_fetch_assoc_prepared('SELECT *
+					FROM aggregate_graphs_graph_item
 					WHERE aggregate_graph_id = ?
 					ORDER BY sequence', array($aggregate_graph_id)),
 				'graph_templates_item_id', array('aggregate_graph_id', 'graph_templates_item_id', 'sequence', 'color_template', 't_graph_type_id', 'graph_type_id', 't_cdef_id', 'cdef_id', 'item_skip', 'item_total')
@@ -320,7 +320,7 @@ function form_actions() {
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Delete Graph(s)') . "'>";
+			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Delete Graph(s)') . "'>";
 		} elseif (get_request_var('drp_action') == '2') { // migrate to aggregate
 			/* determine the common graph template if any */
 			foreach ($_POST as $var => $val) {
@@ -333,13 +333,13 @@ function form_actions() {
 			/* for whatever reason,  subquery performance in mysql is sub-optimal.  Therefore, let's do this
 			 * as a few queries instead.
 			 */
-			$task_items = array_rekey(db_fetch_assoc("SELECT DISTINCT task_item_id 
-				FROM graph_templates_item 
+			$task_items = array_rekey(db_fetch_assoc("SELECT DISTINCT task_item_id
+				FROM graph_templates_item
 				WHERE local_graph_id IN($lgid)"), 'task_item_id', 'task_item_id');
 
 			$task_items = implode(',', $task_items);
 
-			$graph_templates = db_fetch_assoc("SELECT DISTINCT graph_template_id 
+			$graph_templates = db_fetch_assoc("SELECT DISTINCT graph_template_id
 				FROM graph_templates_item
 				WHERE task_item_id IN ($task_items) AND graph_template_id>0");
 
@@ -352,14 +352,14 @@ function form_actions() {
 					</td>
 				</tr>\n";
 
-				$save_html = "<input type='button' value='" . __('Return') . "' onClick='cactiReturnTo()'>";
+				$save_html = "<input type='button' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
 			} else {
 				$graph_template      = $graph_templates[0]['graph_template_id'];
 
-				$aggregate_templates = db_fetch_assoc_prepared('SELECT id, name 
-					FROM aggregate_graph_templates 
-					WHERE graph_template_id = ? 
-					ORDER BY name', 
+				$aggregate_templates = db_fetch_assoc_prepared('SELECT id, name
+					FROM aggregate_graph_templates
+					WHERE graph_template_id = ?
+					ORDER BY name',
 					array($graph_template));
 
 				if (sizeof($aggregate_templates)) {
@@ -381,7 +381,7 @@ function form_actions() {
 						</td>
 					</tr>\n";
 
-					$save_html = "<tr><td colspan='2' align='right'><input type='button' value='" . __('Cancel'). "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Delete Graph(s)') . "'></td></tr>";
+					$save_html = "<tr><td colspan='2' align='right'><input type='button' value='" . __esc('Cancel'). "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Delete Graph(s)') . "'></td></tr>";
 				} else {
 					print "<tr>
 						<td class='textArea'>
@@ -392,7 +392,7 @@ function form_actions() {
 						</td>
 					</tr>\n";
 
-					$save_html = "<input type='button' value='" . __('Return') . "' onClick='cactiReturnTo()'>";
+					$save_html = "<input type='button' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
 				}
 			}
 		} elseif (get_request_var('drp_action') == '3') { // create aggregate from aggregates
@@ -404,9 +404,9 @@ function form_actions() {
 			</tr>\n";
 
 			print "	<tr><td class='textArea' width='170'>" . __('Aggregate Name:') . "</td></tr>\n";
-			print "	<tr><td class='textArea'><input name='aggregate_name' size='40' value='" . __('New Aggregate') . "'></td></tr>\n";
+			print "	<tr><td class='textArea'><input name='aggregate_name' size='40' value='" . __esc('New Aggregate') . "'></td></tr>\n";
 
-			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Delete Graph(s)') . "'>";
+			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Delete Graph(s)') . "'>";
 		} elseif (get_request_var('drp_action') == '10') { // associate with aggregate
 			print "<tr>
 				<td class='textArea'>
@@ -415,7 +415,7 @@ function form_actions() {
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Associate Graph(s)') . "'>";
+			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Associate Graph(s)') . "'>";
 		} elseif (get_request_var('drp_action') == '11') { // dis-associate with aggregate
 			print "<tr>
 				<td class='textArea'>
@@ -424,7 +424,7 @@ function form_actions() {
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Dis-Associate Graph(s)') . "'>";
+			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Dis-Associate Graph(s)') . "'>";
 		} elseif (preg_match("/^tr_([0-9]+)$/", get_request_var('drp_action'), $matches)) { // place on tree
 			print "<tr>
 				<td class='textArea'>
@@ -435,11 +435,11 @@ function form_actions() {
 			</tr>\n
 			<input type='hidden' name='tree_id' value='" . $matches[1] . "'>\n";
 
-			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Place Graph(s) on Tree') . "'>";
+			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Place Graph(s) on Tree') . "'>";
 		}
 	} else {
 		print "<tr><td class='even'><span class='textError'>" . __('You must select at least one graph.') . "</span></td></tr>\n";
-		$save_html = "<input type='button' value='" . __('Return') . "' onClick='cactiReturnTo()'>";
+		$save_html = "<input type='button' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
 	}
 
 	print "	<tr>
@@ -486,14 +486,14 @@ function item() {
 			LEFT JOIN cdef ON (gti.cdef_id=cdef.id)
 			LEFT JOIN colors ON (gti.color_id=colors.id)
 			WHERE gti.local_graph_id = ?
-			ORDER BY gti.sequence', 
+			ORDER BY gti.sequence',
 			array(get_request_var('id')));
 
-		$header_label = __('Graph Items [edit: %s]', htmlspecialchars(get_graph_title(get_request_var('id'))));
+		$header_label = __('Graph Items [edit: %s]', html_escape(get_graph_title(get_request_var('id'))));
 	}
 
-	$graph_template_id = db_fetch_cell_prepared('SELECT graph_template_id 
-		FROM graph_local 
+	$graph_template_id = db_fetch_cell_prepared('SELECT graph_template_id
+		FROM graph_local
 		WHERE id = ?', array(get_request_var('id')));
 
 	if (empty($graph_template_id)) {
@@ -534,48 +534,72 @@ function graph_edit() {
 	$aginfo = array();
 	$graphs = array();
 	if (!isempty_request_var('id')) {
-		$graphs = db_fetch_row_prepared('SELECT * 
-			FROM graph_templates_graph 
-			WHERE local_graph_id = ?', 
+		$graphs = db_fetch_row_prepared('SELECT *
+			FROM graph_templates_graph
+			WHERE local_graph_id = ?',
 			array(get_request_var('id')));
 
-		$aginfo = db_fetch_row_prepared('SELECT * 
-			FROM aggregate_graphs 
+		$aginfo = db_fetch_row_prepared('SELECT *
+			FROM aggregate_graphs
 			WHERE local_graph_id = ?',
 			array($graphs['local_graph_id']));
 
-		$header_label = '[edit: ' . htmlspecialchars(get_graph_title(get_request_var('id'))) . ']';
+		if ($aginfo['title_format'] == '') {
+			$aginfo['title_format'] = get_graph_title($graphs['local_graph_id']);
+		}
+
+		$header_label = '[edit: ' . html_escape(get_graph_title(get_request_var('id'))) . ']';
 	}
 
 	if (sizeof($aginfo)) {
 		if ($aginfo['aggregate_template_id'] > 0) {
-			$template = db_fetch_row_prepared('SELECT * 
-				FROM aggregate_graph_templates 
-				WHERE id = ?', 
+			$template = db_fetch_row_prepared('SELECT *
+				FROM aggregate_graph_templates
+				WHERE id = ?',
 				array($aginfo['aggregate_template_id']));
 		} else {
 			$template = $aginfo;
 		}
 
-		$aggregate_tabs = array('details' => __('Details'), 'items' => __('Items'), 'preview' => __('Preview'));
+		$aggregate_tabs = array(
+			'details' => __('Details'),
+			'items'   => __('Items'),
+			'preview' => __('Preview')
+		);
 	} else {
 		$template = array();
-		$aggregate_tabs = array('details' => __('Details'), 'preview' => __('Preview'));
+		$aggregate_tabs = array(
+			'details' => __('Details'),
+			'preview' => __('Preview')
+		);
 	}
 
 	/* ================= input validation and session storage ================= */
-	$filters = array(
-		'tab' => array(
-			'filter' => FILTER_CALLBACK, 
-			'default' => 'details', 
-			'options' => array('options' => 'sanitize_search_string')
-		)
-	);
+	if (isset_request_var('tab')) {
+		switch(get_nfilter_request_var('tab')) {
+		case 'details':
+		case 'items':
+		case 'preview':
+			$_SESSION['agg_tab'] = get_nfilter_request_var('tab');
+			set_request_var('tab', get_nfilter_request_var('tab'));
 
-	validate_store_request_vars($filters, 'sess_aggregate');
+			break;
+		default:
+			if (isset($_SESSION['agg_tab'])) {
+				set_request_var('tab', $_SESSION['agg_tab']);
+			}else{
+				$_SESSION['agg_tab'] = 'details';
+				set_request_var('tab', 'details');
+			}
+		}
+	} elseif (isset($_SESSION['agg_tab'])) {
+		set_request_var('tab', $_SESSION['agg_tab']);
+	} else {
+		set_request_var('tab', 'details');
+	}
 	/* ================= input validation ================= */
 
-	$current_tab = get_request_var('tab');
+	$current_tab = get_nfilter_request_var('tab');
 
 	/* draw the categories tabs on the top of the page */
 	print "<div class='tabs'>\n";
@@ -585,8 +609,8 @@ function graph_edit() {
 	if (sizeof($aggregate_tabs)) {
 		foreach (array_keys($aggregate_tabs) as $tab_short_name) {
 			if ($tab_short_name == 'details' || (!isempty_request_var('id'))) {
-				print "<li class='subTab'><a class='tab " . ($tab_short_name == $current_tab ? "selected'" : "'") . 
-					" href='" . htmlspecialchars($config['url_path'] . 'aggregate_graphs.php?action=edit&id=' . get_request_var('id') . "&tab=$tab_short_name") . "'>" . $aggregate_tabs[$tab_short_name] . "</a></li>\n";
+				print "<li class='subTab'><a class='tab " . ($tab_short_name == $current_tab ? "selected'" : "'") .
+					" href='" . html_escape($config['url_path'] . 'aggregate_graphs.php?action=edit&id=' . get_request_var('id') . "&tab=$tab_short_name") . "'>" . $aggregate_tabs[$tab_short_name] . "</a></li>\n";
 			}
 
 			$i++;
@@ -610,7 +634,7 @@ function graph_edit() {
 	}
 
 	if (!isempty_request_var('id') && $current_tab == 'preview') {
-		print "<ul style='float:right;'><li><a class='pic' href='" . htmlspecialchars('aggregate_graphs.php?action=edit&id=' . get_request_var('id') . '&tab=' . get_request_var('tab') .  '&debug=' . (isset($_SESSION['graph_debug_mode']) ? '0' : '1')) . "'>" . $message . "</a></li></ul></nav>\n</div></div>\n";
+		print "<ul style='float:right;'><li><a class='pic' href='" . html_escape('aggregate_graphs.php?action=edit&id=' . get_request_var('id') . '&tab=' . get_request_var('tab') .  '&debug=' . (isset($_SESSION['graph_debug_mode']) ? '0' : '1')) . "'>" . $message . "</a></li></ul></nav>\n</div></div>\n";
 	} elseif (!isempty_request_var('id') && $current_tab == 'details' && (!sizeof($template))) {
 		print "<ul style='float:right;'><li><a id='toggle_items' class='pic' href='#'>" . __('Show Item Details') . "</a></li></ul></nav>\n</div></div>\n";
 	} else {
@@ -621,7 +645,7 @@ function graph_edit() {
 		html_start_box(__('Aggregate Preview [%s]', $header_label), '100%', '', '3', 'center', '');
 		?>
 		<tr class='even'><td class='center'>
-			<img src='<?php print htmlspecialchars($config['url_path'] . 'graph_image.php?action=edit&disable_cache=1&local_graph_id=' . get_request_var('id') . '&rra_id=' . read_user_setting('default_rra_id') . '&random=' . mt_rand());?>' alt=''>
+			<img src='<?php print html_escape($config['url_path'] . 'graph_image.php?action=edit&disable_cache=1&local_graph_id=' . get_request_var('id') . '&rra_id=' . read_user_setting('default_rra_id') . '&random=' . mt_rand());?>' alt=''>
 		</td></tr>
 		<?php
 		if (isset($_SESSION['graph_debug_mode']) && isset_request_var('id')) {
@@ -630,9 +654,9 @@ function graph_edit() {
 			?>
 			<tr><td class='left'>
 				<div style='overflow:auto;'>
-				<span class='textInfo'><?php print __('RRDTool Command:');?></span><br>
+				<span class='textInfo'><?php print __('RRDtool Command:');?></span><br>
 				<pre class='monoSpace'><?php print @rrdtool_function_graph(get_request_var('id'), 1, $graph_data_array);?></pre>
-				<span class='textInfo'><?php print __('RRDTool Says:');?></span><br>
+				<span class='textInfo'><?php print __('RRDtool Says:');?></span><br>
 				<?php unset($graph_data_array['print_source']);?>
 				<pre class='monoSpace'><?php print @rrdtool_function_graph(get_request_var('id'), 1, $graph_data_array);?></pre>
 				</div>
@@ -673,7 +697,6 @@ function graph_edit() {
 				draw_aggregate_graph_items_list(0, $template['graph_template_id'], $aginfo);
 			}
 
-			form_hidden_box('id', (isset($template['id']) ? $template['id'] : '0'), '');
 			form_hidden_box('save_component_template', '1', '');
 
 			?>
@@ -833,8 +856,8 @@ function graph_edit() {
 
 						$form_array[$field_name]['value']   = (isset($graphs) ? $graphs[$field_name] : '');
 						$form_array[$field_name]['form_id'] = (isset($graphs) ? $graphs['id'] : '0');
-	
-						if (!(($use_graph_template == false) || ($graphs_template{'t_' . $field_name} == 'on'))) {
+
+						if (!(($use_graph_template == false) || ($graphs_template['t_' . $field_name] == 'on'))) {
 							$form_array[$field_name]['method']      = 'template_' . $form_array[$field_name]['method'];
 							$form_array[$field_name]['description'] = '';
 						}
@@ -911,38 +934,37 @@ function aggregate_items() {
 	/* ================= input validation and session storage ================= */
 	$filters = array(
 		'rows' => array(
-			'filter' => FILTER_VALIDATE_INT, 
+			'filter' => FILTER_VALIDATE_INT,
 			'pageset' => true,
 			'default' => '-1'
 			),
 		'template_id' => array(
-			'filter' => FILTER_VALIDATE_INT, 
+			'filter' => FILTER_VALIDATE_INT,
 			'pageset' => true,
 			'default' => '-1'
 			),
-		'filter' => array(
-			'filter' => FILTER_CALLBACK, 
+		'rfilter' => array(
+			'filter'  => FILTER_VALIDATE_IS_REGEX,
 			'pageset' => true,
-			'default' => '', 
-			'options' => array('options' => 'sanitize_search_string')
+			'default' => ''
 			),
 		'page' => array(
-			'filter' => FILTER_VALIDATE_INT, 
+			'filter' => FILTER_VALIDATE_INT,
 			'default' => '1'
 			),
 		'matching' => array(
-			'filter' => FILTER_CALLBACK, 
-			'default' => 'on', 
+			'filter' => FILTER_CALLBACK,
+			'default' => 'on',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 		'sort_column' => array(
-			'filter' => FILTER_CALLBACK, 
-			'default' => 'title_cache', 
+			'filter' => FILTER_CALLBACK,
+			'default' => 'title_cache',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 		'sort_direction' => array(
-			'filter' => FILTER_CALLBACK, 
-			'default' => 'ASC', 
+			'filter' => FILTER_CALLBACK,
+			'default' => 'ASC',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 	);
@@ -962,15 +984,14 @@ function aggregate_items() {
 	function applyFilter() {
 		strURL = 'aggregate_graphs.php?action=edit&tab=items&id='+$('#id').val();
 		strURL += '&rows=' + $('#rows').val();
-		strURL += '&page=' + $('#page').val();
-		strURL += '&filter=' + escape($('#filter').val());
+		strURL += '&rfilter=' + $('#rfilter').val();
 		strURL += '&matching=' + $('#matching').is(':checked');
 		strURL += '&header=false';
 		loadPageNoHeader(strURL);
 	}
 
 	function clearFilter() {
-		strURL = 'aggregate_graphs.php?action=edit&tab=items&id='+$('#id').val()+'&clear=1&header=false';
+		strURL = 'aggregate_graphs.php?action=edit&tab=items&id='+$('#id').val()+'&clear=true&header=false';
 		loadPageNoHeader(strURL);
 	}
 
@@ -983,7 +1004,7 @@ function aggregate_items() {
 			clearFilter();
 		});
 
-		$('#filter').change(function() {
+		$('#rfilter').change(function() {
 			applyFilter();
 		});
 
@@ -1007,7 +1028,7 @@ function aggregate_items() {
 						<?php print __('Search');?>
 					</td>
 					<td>
-						<input type='text' id='filter' size='25' onChange='applyFilter()' value='<?php print htmlspecialchars(get_request_var('filter'));?>'>
+						<input type='text' id='rfilter' size='45' onChange='applyFilter()' value='<?php print get_request_var('rfilter');?>'>
 					</td>
 					<td>
 						<?php print __('Graphs');?>
@@ -1018,27 +1039,26 @@ function aggregate_items() {
 							<?php
 							if (sizeof($item_rows) > 0) {
 								foreach ($item_rows as $key => $value) {
-									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . htmlspecialchars($value) . "</option>\n";
+									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>\n";
 								}
 							}
 							?>
 						</select>
 					</td>
 					<td>
-						<input type='checkbox' id='matching' onChange='applyFilter()' <?php print (get_request_var('matching') == 'on' || get_request_var('matching') == 'true' ? ' checked':'');?>>
+						<span>
+							<input type='checkbox' id='matching' onChange='applyFilter()' <?php print (get_request_var('matching') == 'on' || get_request_var('matching') == 'true' ? ' checked':'');?>>
+							<label for='matching'><?php print __('Part of Aggregate');?></label>
+						</span>
 					</td>
 					<td>
-						<label for='matching'><?php print __('Part of Aggregate');?></label>
-					</td>
-					<td>
-						<input id='refresh' type='button' value='<?php print __('Go');?>' title='<?php print __('Set/Refresh Filters');?>'>
-					</td>
-					<td>
-						<input id='clear' type='button' onClick='clearFilter()' value='<?php print __('Clear');?>' title='<?php print __('Clear Filters');?>'>
+						<span>
+							<input id='refresh' type='button' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
+							<input id='clear' type='button' onClick='clearFilter()' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
+						</span>
 					</td>
 				</tr>
 			</table>
-			<input type='hidden' id='page' value='<?php print get_request_var('page');?>'>
 			<input type='hidden' name='action' value='edit'>
 			<input type='hidden' name='tab' value='items'>
 			<input type='hidden' id='id' value='<?php print get_request_var('id');?>'>
@@ -1050,14 +1070,14 @@ function aggregate_items() {
 	html_end_box(false);
 
 	/* form the 'where' clause for our main sql query */
-	if (get_request_var('filter') != '') {
-		$filters = explode(' ', get_request_var('filter'));
+	if (get_request_var('rfilter') == '') {
+		$sql_where = '';
+	} elseif (validate_is_regex(get_request_var('rfilter'))) {
+		$sql_where = 'WHERE gtg.title_cache RLIKE "' . get_request_var('rfilter') . '"';
+	} else {
+		$filters = explode(' ', get_request_var('rfilter'));
 		$sql_where = '';
 		$sql_where = aggregate_make_sql_where($sql_where, $filters, 'gtg.title_cache');
-
-		//$sql_where = "WHERE (gtg.title_cache LIKE '%%" . get_request_var("filter") . "%%')";
-	} else {
-		$sql_where = '';
 	}
 
 	if (get_request_var('matching') != 'false') {
@@ -1066,16 +1086,16 @@ function aggregate_items() {
 
 	$graph_template = db_fetch_cell_prepared('SELECT graph_template_id
 		FROM aggregate_graphs AS ag
-		WHERE ag.local_graph_id = ?', 
+		WHERE ag.local_graph_id = ?',
 		array(get_request_var('id')));
 
-	$aggregate_id   = db_fetch_cell_prepared('SELECT id 
-		FROM aggregate_graphs 
-		WHERE local_graph_id = ?', 
+	$aggregate_id = db_fetch_cell_prepared('SELECT id
+		FROM aggregate_graphs
+		WHERE local_graph_id = ?',
 		array(get_request_var('id')));
 
 	if (!empty($graph_template)) {
-		$sql_where .= ($sql_where != '' ? ' AND':'WHERE') . "(gtg.graph_template_id=$graph_template)";
+		$sql_where .= ($sql_where != '' ? ' AND':'WHERE') . " (gtg.graph_template_id=$graph_template)";
 	}
 
 	/* print checkbox form for validation */
@@ -1083,7 +1103,7 @@ function aggregate_items() {
 
 	html_start_box('', '100%', '', '3', 'center', '');
 
-	$total_rows = db_fetch_cell("SELECT COUNT(gtg.id) AS total
+	$total_rows = db_fetch_cell("SELECT COUNT(DISTINCT gl.id) AS total
 		FROM graph_templates_graph AS gtg
 		INNER JOIN graph_local AS gl
 		ON gtg.local_graph_id=gl.id
@@ -1124,7 +1144,13 @@ function aggregate_items() {
 		foreach ($graph_list as $graph) {
 			/* we're escaping strings here, so no need to escape them on form_selectable_cell */
 			form_alternate_row('line' . $graph['local_graph_id'], true);
-			form_selectable_cell(get_request_var('filter') != '' ? aggregate_format_text(htmlspecialchars($graph['title_cache']), get_request_var('filter')) : htmlspecialchars($graph['title_cache']), $graph['local_graph_id']);
+
+			if (validate_is_regex(get_request_var('rfilter'))) {
+				form_selectable_cell(filter_value($graph['title_cache'], get_request_var('rfilter')), $graph['local_graph_id']);
+			} else {
+				form_selectable_cell(get_request_var('rfilter') != '' ? aggregate_format_text(html_escape($graph['title_cache']), get_request_var('rfilter')) : html_escape($graph['title_cache']), $graph['local_graph_id']);
+			}
+
 			form_selectable_cell($graph['local_graph_id'], $graph['local_graph_id'], '', 'right');
 			form_selectable_cell(($graph['agg_graph_id'] != '' ? "<span class='associated'>" . __('Yes') . '</span>':"<span class='notAssociated'>" . __('No') . "</span>"), $graph['local_graph_id']);
 			form_selectable_cell($graph['height'] . 'x' . $graph['width'], $graph['local_graph_id'], '', 'right');
@@ -1139,7 +1165,7 @@ function aggregate_items() {
 
 	/* put the nav bar on the bottom as well */
 	print $nav;
-	
+
 	/* add a list of tree names to the actions dropdown */
 	add_tree_names_to_actions_array();
 
@@ -1159,43 +1185,48 @@ function aggregate_make_sql_where($sql_where, $items, $field) {
 	}
 
 	$indentation = 0;
+	$termcount   = 0;
 
 	if (sizeof($items)) {
-	foreach($items as $i) {
-		$i = trim($i);
-		while (substr($i,0,1) == '(') {
-			$indentation++;
-			$sql_where .= '(';
-			$i = substr($i,1);
-		}
+		foreach($items as $i) {
+			$i = trim($i);
+			while (substr($i,0,1) == '(') {
+				$indentation++;
+				$termcount = 0;
+				$sql_where .= '(';
+				$i = substr($i, 1);
+			}
 
-		$split = strpos($i, ')');
-		if ($split !== false) {
-			$end = trim(substr($i,$split));
-			$i   = substr($i,0,$split);
-		} else {
-			$end = '';
-		}
-
-		if ($i != '') {
-			if (strtolower($i) == 'and') {
-				$sql_where .= ' AND ';
-			} elseif (strtolower($i) == 'or') {
-				$sql_where .= ' OR ';
+			$split = strpos($i, ')');
+			if ($split !== false) {
+				$end = trim(substr($i, $split));
+				$i   = substr($i, 0, $split);
 			} else {
-				$sql_where .= $field . " LIKE '%%" . trim($i) . "%%'";
+				$end = '';
 			}
-		}
 
-		if ($end != '') {
-			while (substr($end,0,1) == ')') {
-				$indentation--;
-				$sql_where .= ')';
-				$end = trim(substr($end,1));
+			if ($i != '') {
+				if (strtolower($i) == 'and') {
+					$sql_where .= ' AND ';
+				} elseif (strtolower($i) == 'or') {
+					$sql_where .= ' OR ';
+				} else {
+					$sql_where .= ($termcount > 0 ? ' OR ':'') . $field . " LIKE '%" . trim($i) . "%'";
+					$termcount++;
+				}
+			}
+
+			if ($end != '') {
+				while (substr($end, 0, 1) == ')') {
+					$indentation--;
+					$termcount = 0;
+					$sql_where .= ')';
+					$end = trim(substr($end, 1));
+				}
 			}
 		}
 	}
-	}
+
 	$sql_where .= ')';
 
 	return trim($sql_where);
@@ -1221,7 +1252,7 @@ function aggregate_format_text($text, $filter) {
 
 	if (sizeof($tags)) {
 		foreach($tags as $k => $t) {
-			$text = str_replace("<<$k>>", "<span class='filteredValue'>" . htmlspecialchars($t) . "</span>", $text);
+			$text = str_replace("<<$k>>", "<span class='filteredValue'>" . html_escape($t) . "</span>", $text);
 		}
 	}
 
@@ -1234,33 +1265,33 @@ function aggregate_graph() {
 	/* ================= input validation and session storage ================= */
 	$filters = array(
 		'rows' => array(
-			'filter' => FILTER_VALIDATE_INT, 
+			'filter' => FILTER_VALIDATE_INT,
 			'pageset' => true,
 			'default' => '-1'
 			),
 		'template_id' => array(
-			'filter' => FILTER_VALIDATE_INT, 
+			'filter' => FILTER_VALIDATE_INT,
 			'pageset' => true,
 			'default' => '-1'
 			),
 		'filter' => array(
-			'filter' => FILTER_CALLBACK, 
+			'filter' => FILTER_CALLBACK,
 			'pageset' => true,
-			'default' => '', 
+			'default' => '',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 		'page' => array(
-			'filter' => FILTER_VALIDATE_INT, 
+			'filter' => FILTER_VALIDATE_INT,
 			'default' => '1'
 			),
 		'sort_column' => array(
-			'filter' => FILTER_CALLBACK, 
-			'default' => 'title_cache', 
+			'filter' => FILTER_CALLBACK,
+			'default' => 'title_cache',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 		'sort_direction' => array(
-			'filter' => FILTER_CALLBACK, 
-			'default' => 'ASC', 
+			'filter' => FILTER_CALLBACK,
+			'default' => 'ASC',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 	);
@@ -1280,8 +1311,7 @@ function aggregate_graph() {
 	function applyFilter() {
 		strURL  = 'aggregate_graphs.php';
 		strURL += '?rows=' + $('#rows').val();
-		strURL += '&page=' + $('#page').val();
-		strURL += '&filter=' + escape($('#filter').val());
+		strURL += '&filter=' + $('#filter').val();
 		strURL += '&template_id=' + $('#template_id').val();
 		strURL += '&header=false';
 		loadPageNoHeader(strURL);
@@ -1326,7 +1356,7 @@ function aggregate_graph() {
 						<?php print __('Search');?>
 					</td>
 					<td>
-						<input type='text' id='filter' size='25' value='<?php print htmlspecialchars(get_request_var('filter'));?>'>
+						<input type='text' id='filter' size='25' value='<?php print get_request_var('filter');?>'>
 					</td>
 					<td>
 						<?php print __('Template');?>
@@ -1344,7 +1374,7 @@ function aggregate_graph() {
 
 							if (sizeof($templates) > 0) {
 								foreach ($templates as $template) {
-									print "<option value='" . $template['id'] . "'"; if (get_request_var('template_id') == $template['id']) { print ' selected'; } print '>' . htmlspecialchars($template['name']) . "</option>\n";
+									print "<option value='" . $template['id'] . "'"; if (get_request_var('template_id') == $template['id']) { print ' selected'; } print '>' . html_escape($template['name']) . "</option>\n";
 								}
 							}
 							?>
@@ -1359,21 +1389,20 @@ function aggregate_graph() {
 							<?php
 							if (sizeof($item_rows) > 0) {
 								foreach ($item_rows as $key => $value) {
-									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . htmlspecialchars($value) . "</option>\n";
+									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>\n";
 								}
 							}
 							?>
 						</select>
 					</td>
 					<td>
-						<input type='button' id='refresh' value='<?php print __('Go');?>' title='<?php print __('Set/Refresh Filters');?>'>
-					</td>
-					<td>
-						<input type='button' id='clear' value='<?php print __('Clear');?>' title='<?php print __('Clear Filters');?>'>
+						<span>
+							<input type='button' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
+							<input type='button' id='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
+						</span>
 					</td>
 				</tr>
 			</table>
-			<input type='hidden' id='page' name='page' value='<?php print get_request_var('page');?>'>
 			</form>
 		</td>
 	</tr>
@@ -1384,8 +1413,8 @@ function aggregate_graph() {
 	$sql_where = 'WHERE (gtg.graph_template_id=0 AND gl.host_id=0)';
 	/* form the 'where' clause for our main sql query */
 	if (get_request_var('filter') != '') {
-		$sql_where .= " AND (gtg.title_cache LIKE '%%" . get_request_var('filter') . "%%'" .
-			" OR ag.title_format LIKE '%%" . get_request_var('filter') . "%%')";
+		$sql_where .= " AND (gtg.title_cache LIKE '%" . get_request_var('filter') . "%'" .
+			" OR ag.title_format LIKE '%" . get_request_var('filter') . "%')";
 	}
 
 	if (get_request_var('template_id') == '-1') {
@@ -1396,11 +1425,11 @@ function aggregate_graph() {
 		$sql_where .= ' AND ag.aggregate_template_id=' . get_request_var('template_id');
 	}
 
-	$total_rows = db_fetch_cell("SELECT COUNT(gtg.id) AS total
+	$total_rows = db_fetch_cell("SELECT COUNT(DISTINCT gl.id) AS total
 		FROM graph_templates_graph AS gtg
 		INNER JOIN graph_local AS gl
 		ON gtg.local_graph_id=gl.id
-		LEFT JOIN aggregate_graphs AS ag
+		INNER JOIN aggregate_graphs AS ag
 		ON gtg.local_graph_id=ag.local_graph_id
 		LEFT JOIN aggregate_graph_templates AS agt
 		ON agt.id=ag.aggregate_template_id
@@ -1414,8 +1443,8 @@ function aggregate_graph() {
 		FROM graph_templates_graph AS gtg
 		INNER JOIN graph_local AS gl
 		ON gtg.local_graph_id=gl.id
-		LEFT JOIN aggregate_graphs AS ag
-		ON gtg.local_graph_id=ag.local_graph_id
+		INNER JOIN aggregate_graphs AS ag
+		ON gl.id=ag.local_graph_id
 		LEFT JOIN aggregate_graph_templates AS agt
 		ON agt.id=ag.aggregate_template_id
 		$sql_where
@@ -1443,7 +1472,7 @@ function aggregate_graph() {
 	if (sizeof($graph_list)) {
 		foreach ($graph_list as $graph) {
 			/* we're escaping strings here, so no need to escape them on form_selectable_cell */
-			$template_name = htmlspecialchars($graph['name']);
+			$template_name = html_escape($graph['name']);
 			form_alternate_row('line' . $graph['local_graph_id'], true);
 			form_selectable_cell(filter_value(title_trim($graph['title_cache'], read_config_option('max_title_length')), get_request_var('filter'), 'aggregate_graphs.php?action=edit&id=' . $graph['local_graph_id']), $graph['local_graph_id']);
 			form_selectable_cell($graph['local_graph_id'], $graph['local_graph_id'], '', 'right');
@@ -1500,13 +1529,13 @@ function purge_old_graphs() {
 		WHERE gl.id IS NULL'), 'id', 'id');
 
 	if (sizeof($old_aggregates)) {
-		db_execute('DELETE FROM graph_templates_item 
+		db_execute('DELETE FROM graph_templates_item
 			WHERE local_graph_id IN (' . implode(',', $old_aggregates) . ')');
 
-		db_execute('DELETE FROM graph_templates_graph 
+		db_execute('DELETE FROM graph_templates_graph
 			WHERE local_graph_id IN (' . implode(',', $old_aggregates) . ')');
 
-		db_execute('DELETE FROM aggregate_graphs 
+		db_execute('DELETE FROM aggregate_graphs
 			WHERE local_graph_id IN (' . implode(',', $old_aggregates) . ')');
 	}
 
