@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -64,6 +64,11 @@ switch (get_request_var('action')) {
 		automation_graph_rules_item_edit();
 		bottom_footer();
 		break;
+	case 'qedit':
+		automation_change_query_type();
+
+		header('Location: automation_graph_rules.php?header=false&action=edit&name=' . get_request_var('name') . '&id=' . get_filter_request_var('id'));
+		break;
 	case 'remove':
 		automation_graph_rules_remove();
 
@@ -243,7 +248,7 @@ function automation_graph_rules_form_actions() {
 
 	form_start('automation_graph_rules.php', 'automation_graph_rules');
 
-	html_start_box($automation_graph_rules_actions{get_nfilter_request_var('drp_action')}, '60%', '', '3', 'center', '');
+	html_start_box($automation_graph_rules_actions[get_nfilter_request_var('drp_action')], '60%', '', '3', 'center', '');
 
 	if (get_nfilter_request_var('drp_action') == AUTOMATION_ACTION_GRAPH_DELETE) { /* delete */
 		print "<tr>
@@ -279,9 +284,9 @@ function automation_graph_rules_form_actions() {
 
 	if (!isset($automation_graph_rules_array)) {
 		print "<tr class='even'><td><span class='textError'>" . __('You must select at least one Rule.') . "</span></td></tr>\n";
-		$save_html = "<input type='button' value='" . __('Return') . "' onClick='cactiReturnTo()'>";
+		$save_html = "<input type='button' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
 	}else {
-		$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Apply requested action') . "'>";
+		$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Apply requested action') . "'>";
 	}
 
 	print "	<tr>
@@ -366,7 +371,7 @@ function automation_graph_rules_item_edit() {
 		form_hidden_box('save_component_automation_graph_rule_item', '1', '');
 	}
 
-	form_save_button(htmlspecialchars('automation_graph_rules.php?action=edit&id=' . get_request_var('id') . '&rule_type='. get_request_var('rule_type')));
+	form_save_button('automation_graph_rules.php?action=edit&id=' . get_request_var('id') . '&rule_type='. get_request_var('rule_type'));
 
 	?>
 	<script type='text/javascript'>
@@ -432,6 +437,42 @@ function automation_graph_rules_remove() {
 	}
 }
 
+function automation_change_query_type() {
+	$id = get_filter_request_var('id');
+
+	if (isset_request_var('snmp_query_id') && $id > 0) {
+		$snmp_query_id = get_filter_request_var('snmp_query_id');
+		$name = get_nfilter_request_var('name');
+
+		db_execute_prepared('UPDATE automation_graph_rules
+			SET snmp_query_id = ?, name = ?
+			WHERE id = ?',
+			array($snmp_query_id, $name, $id));
+
+		$graph_type = db_fetch_cell_prepared('SELECT id
+			FROM snmp_query_graph
+			WHERE snmp_query_id = ?
+			ORDER BY name
+			LIMIT 1', array($snmp_query_id));
+
+		db_execute_prepared('UPDATE automation_graph_rules
+			SET graph_type_id = ?
+			WHERE id = ?',
+			array($graph_type, $id));
+
+		raise_message(1);
+	} elseif (isset_request_var('graph_type_id') && $id > 0) {
+		$snmp_query_id = get_filter_request_var('graph_type_id');
+		$name = get_nfilter_request_var('name');
+
+		db_execute_prepared('UPDATE automation_graph_rules
+			SET graph_type_id = ?, name = ?
+			WHERE id = ?',
+			array($snmp_query_id, $name, $id));
+
+		raise_message(1);
+	}
+}
 
 function automation_graph_rules_edit() {
 	global $config;
@@ -494,7 +535,7 @@ function automation_graph_rules_edit() {
 		}
 
 		# setup header
-		$header_label = __('Rule Selection [edit: %s]', htmlspecialchars($rule['name']));
+		$header_label = __('Rule Selection [edit: %s]', html_escape($rule['name']));
 	} else {
 		$rule = array (
 				'name' => get_request_var('name'),
@@ -510,7 +551,7 @@ function automation_graph_rules_edit() {
 		?>
 <table style='width:100%;text-align:center;'>
 	<tr>
-		<td class='textInfo right' style='vertical-align:top;'><span class='linkMarker'>*<a class='linkEditMain' href='<?php print htmlspecialchars('automation_graph_rules.php?action=edit&id=' . (isset_request_var('id') ? get_request_var('id') : 0) . '&show_rule=') . ($_SESSION['automation_graph_rules_show_rule'] == true ? '0' : '1');?>'><?php print ($_SESSION['automation_graph_rules_show_rule'] == true ? __('Don\'t Show'):__('Show'));?> <?php print __('Rule Details.');?></a></span><br>
+		<td class='textInfo right' style='vertical-align:top;'><span class='linkMarker'>*</span><a class='linkEditMain' href='<?php print html_escape('automation_graph_rules.php?action=edit&id=' . (isset_request_var('id') ? get_request_var('id') : 0) . '&show_rule=') . ($_SESSION['automation_graph_rules_show_rule'] == true ? '0' : '1');?>'><?php print ($_SESSION['automation_graph_rules_show_rule'] == true ? __('Don\'t Show'):__('Show'));?> <?php print __('Rule Details.');?></a><br>
 		</td>
 	</tr>
 </table>
@@ -525,7 +566,7 @@ function automation_graph_rules_edit() {
 		?>
 <table style='width:100%;text-align:center;'>
 	<tr>
-		<td class='textInfo right' style='vertical-align:top;'><span class='linkMarker'>*<a class='linkEditMain' href='<?php print htmlspecialchars('automation_graph_rules.php?action=edit&id=' . (isset_request_var('id') ? get_request_var('id') : 0) . '&show_hosts=') . (isset($_SESSION['automation_graph_rules_show_hosts']) ? '0' : '1');?>'><?php print (isset($_SESSION['automation_graph_rules_show_hosts']) ? __('Don\'t Show'):__('Show'));?> <?php print __('Matching Devices.');?></a></span><br>
+		<td class='textInfo right' style='vertical-align:top;'><span class='linkMarker'>*</span><a class='linkEditMain' href='<?php print html_escape('automation_graph_rules.php?action=edit&id=' . (isset_request_var('id') ? get_request_var('id') : 0) . '&show_hosts=') . (isset($_SESSION['automation_graph_rules_show_hosts']) ? '0' : '1');?>'><?php print (isset($_SESSION['automation_graph_rules_show_hosts']) ? __('Don\'t Show'):__('Show'));?> <?php print __('Matching Devices.');?></a><br>
 		</td>
 	</tr>
 </table>
@@ -541,7 +582,7 @@ function automation_graph_rules_edit() {
 <table style='width:100%;text-align:center;'>
 	<tr>
 		<td class='textInfo right' style='vertical-align:top;'>
-			<span class='linkMarker'>*<a class='linkEditMain' href='<?php print htmlspecialchars('automation_graph_rules.php?action=edit&id=' . (isset_request_var('id') ? get_request_var('id') : 0) . '&show_graphs=') . (isset($_SESSION['automation_graph_rules_show_graphs']) ? '0' : '1');?>'><?php print (isset($_SESSION['automation_graph_rules_show_graphs']) ? __('Don\'t Show'):__('Show'));?> <?php print __('Matching Objects.');?></a></span><br>
+			<span class='linkMarker'>*</span><a class='linkEditMain' href='<?php print html_escape('automation_graph_rules.php?action=edit&id=' . (isset_request_var('id') ? get_request_var('id') : 0) . '&show_graphs=') . (isset($_SESSION['automation_graph_rules_show_graphs']) ? '0' : '1');?>'><?php print (isset($_SESSION['automation_graph_rules_show_graphs']) ? __('Don\'t Show'):__('Show'));?> <?php print __('Matching Objects.');?></a><br>
 		</td>
 	</tr>
 </table>
@@ -561,6 +602,10 @@ function automation_graph_rules_edit() {
 			$form_array = $fields_automation_graph_rules_edit1;
 		}
 
+		if (isset_request_var('name')) {
+			$rule['name'] = get_request_var('name');
+		}
+
 		draw_edit_form(array(
 			'config' => array('no_form_tag' => true),
 			'fields' => inject_form_variables($form_array, (isset($rule) ? $rule : array()))
@@ -613,19 +658,20 @@ function automation_graph_rules_edit() {
 	?>
 	<script type='text/javascript'>
 	function applySNMPQueryIdChange() {
-		strURL = 'automation_graph_rules.php?action=edit&id=' + $('#id').val();
-		strURL = strURL + '&snmp_query_id=' + $('#snmp_query_id').val();
-		strURL = strURL + '&name=' + $('#name').val();
-		strURL = strURL + '&header=false';
+		strURL  = 'automation_graph_rules.php?action=qedit';
+		strURL += '&id=' + $('#id').val();
+		strURL += '&name=' + $('#name').val();
+		strURL += '&snmp_query_id=' + $('#snmp_query_id').val();
+		strURL += '&header=false';
 		loadPageNoHeader(strURL);
 	}
 
 	function applySNMPQueryTypeChange() {
-		strURL = 'automation_graph_rules.php?action=edit&id=' + $('#id').val();
-		strURL = strURL + '&snmp_query_id=' + $('#snmp_query_id').val();
-		strURL = strURL + '&name=' + $('#name').val();
-		strURL = strURL + '&snmp_query_type' + $('#name').val();
-		strURL = strURL + '&header=false';
+		strURL  = 'automation_graph_rules.php?action=qedit'
+		strURL += '&id=' + $('#id').val();
+		strURL += '&name=' + $('#name').val();
+		strURL += '&graph_type_id=' + $('#graph_type_id').val();
+		strURL += '&header=false';
 		loadPageNoHeader(strURL);
 	}
 	</script>
@@ -701,7 +747,7 @@ function automation_graph_rules() {
 							<?php print __('Search');?>
 						</td>
 						<td>
-							<input type='text' id='filter' size='25' value='<?php print get_request_var('filter');?>'>
+							<input type='text' id='filter' size='25' value='<?php print html_escape_request_var('filter');?>'>
 						</td>
 						<td>
 							<?php print __('Data Query');?>
@@ -711,15 +757,15 @@ function automation_graph_rules() {
 								<option value='-1'<?php print (get_request_var('snmp_query_id') == '-1' ? ' selected':'');?>><?php print __('Any');?></option>
 								<?php
 								$available_data_queries = db_fetch_assoc('SELECT DISTINCT
-									ar.snmp_query_id, sq.name
+									sq.id, sq.name
 									FROM automation_graph_rules AS ar
 									LEFT JOIN snmp_query AS sq
-									ON (ar.snmp_query_id=sq.id)
+									ON ar.snmp_query_id=sq.id
 									ORDER BY sq.name');
 
 								if (sizeof($available_data_queries)) {
 									foreach ($available_data_queries as $data_query) {
-										print "<option value='" . $data_query['snmp_query_id'] . "'" . (get_request_var('snmp_query_id') == $data_query['snmp_query_id'] ? ' selected':'') .  '>' . $data_query['name'] . "</option>\n";
+										print "<option value='" . $data_query['id'] . "'" . (get_request_var('snmp_query_id') == $data_query['id'] ? ' selected':'') .  '>' . $data_query['name'] . "</option>\n";
 									}
 								}
 								?>
@@ -752,8 +798,8 @@ function automation_graph_rules() {
 						</td>
 						<td>
 							<span>
-								<input type='submit' id='refresh' name='go' value='<?php print __('Go');?>'>
-								<input type='button' id='clear' value='<?php print __('Clear');?>'></td>
+								<input type='submit' id='refresh' name='go' value='<?php print __esc('Go');?>'>
+								<input type='button' id='clear' value='<?php print __esc('Clear');?>'></td>
 							</span>
 					</tr>
 				</table>
@@ -762,7 +808,7 @@ function automation_graph_rules() {
 		function applyFilter() {
 			strURL = 'automation_graph_rules.php' +
 				'?status='        + $('#status').val()+
-				'&filter='        + escape($('#filter').val())+
+				'&filter='        + $('#filter').val()+
 				'&rows='          + $('#rows').val()+
 				'&snmp_query_id=' + $('#snmp_query_id').val()+
 				'&header=false';
@@ -861,8 +907,8 @@ function automation_graph_rules() {
 
 	if (sizeof($automation_graph_rules_list)) {
 		foreach ($automation_graph_rules_list as $automation_graph_rules) {
-			$snmp_query_name 		= ((empty($automation_graph_rules['snmp_query_name'])) 	 ? __('None') : htmlspecialchars($automation_graph_rules['snmp_query_name']));
-			$graph_type_name 		= ((empty($automation_graph_rules['graph_type_name'])) 	 ? __('None') : htmlspecialchars($automation_graph_rules['graph_type_name']));
+			$snmp_query_name 		= ((empty($automation_graph_rules['snmp_query_name'])) 	 ? __('None') : html_escape($automation_graph_rules['snmp_query_name']));
+			$graph_type_name 		= ((empty($automation_graph_rules['graph_type_name'])) 	 ? __('None') : html_escape($automation_graph_rules['graph_type_name']));
 
 			form_alternate_row('line' . $automation_graph_rules['id'], true);
 
