@@ -14,7 +14,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -54,12 +54,12 @@ if (sizeof($parms)) {
 	$hostId         = 0;
 	$hostGroupStyle = 1; # 1 = Graph Template,  2 = Data Query Index
 
-	$quietMode      = FALSE;
-	$displayHosts   = FALSE;
-	$displayTrees   = FALSE;
-	$displayNodes   = FALSE;
-	$displayRRAs    = FALSE;
-	$displayGraphs  = FALSE;
+	$quietMode      = false;
+	$displayHosts   = false;
+	$displayTrees   = false;
+	$displayNodes   = false;
+	$displayRRAs    = false;
+	$displayGraphs  = false;
 
 	$hosts          = getHosts();
 
@@ -72,80 +72,76 @@ if (sizeof($parms)) {
 		}
 
 		switch ($arg) {
-		case '--type':
-			$type = trim($value);
+			case '--type':
+				$type = trim($value);
 
-			break;
-		case '--name':
-			$name = trim($value);
+				break;
+			case '--name':
+				$name = trim($value);
 
-			break;
-		case '--sort-method':
-			$sortMethod = trim($value);
+				break;
+			case '--sort-method':
+				$sortMethod = trim($value);
 
-			break;
-		case '--parent-node':
-			$parentNode = $value;
+				break;
+			case '--parent-node':
+				$parentNode = $value;
 
-			break;
-		case '--tree-id':
-			$treeId = $value;
+				break;
+			case '--tree-id':
+				$treeId = $value;
 
-			break;
-		case '--node-type':
-			$nodeType = trim($value);
+				break;
+			case '--node-type':
+				$nodeType = trim($value);
 
-			break;
-		case '--graph-id':
-			$graphId = $value;
+				break;
+			case '--graph-id':
+				$graphId = $value;
 
-			break;
-		case '--host-id':
-			$hostId = $value;
+				break;
+			case '--host-id':
+				$hostId = $value;
 
-			break;
-		case '--quiet':
-			$quietMode = TRUE;
+				break;
+			case '--quiet':
+				$quietMode = true;
 
-			break;
-		case '--list-hosts':
-			$displayHosts = TRUE;
+				break;
+			case '--list-hosts':
+				$displayHosts = true;
 
-			break;
-		case '--list-trees':
-			$displayTrees = TRUE;
+				break;
+			case '--list-trees':
+				$displayTrees = true;
 
-			break;
-		case '--list-nodes':
-			$displayNodes = TRUE;
+				break;
+			case '--list-nodes':
+				$displayNodes = true;
 
-			break;
-		case '--list-graphs':
-			$displayGraphs = TRUE;
+				break;
+			case '--list-graphs':
+				$displayGraphs = true;
 
-			break;
-		case '--host-group-style':
-			$hostGroupStyle = trim($value);
+				break;
+			case '--host-group-style':
+				$hostGroupStyle = trim($value);
 
-			break;
-		case '--quiet':
-			$quietMode = TRUE;
-
-			break;
-		case '--version':
-		case '-V':
-		case '-v':
-			display_version();
-			exit;
-		case '--help':
-		case '-H':
-		case '-h':
-			display_help();
-			exit;
-		default:
-			echo "ERROR: Invalid Argument: ($arg)\n\n";
-			display_help();
-			exit(1);
+				break;
+			case '--version':
+			case '-V':
+			case '-v':
+				display_version();
+				exit;
+			case '--help':
+			case '-H':
+			case '-h':
+				display_help();
+				exit;
+			default:
+				echo "ERROR: Invalid Argument: ($arg)\n\n";
+				display_help();
+				exit(1);
 		}
 	}
 
@@ -311,7 +307,7 @@ if (sizeof($parms)) {
 
 /*  display_version - displays version information */
 function display_version() {
-	$version = db_fetch_cell('SELECT cacti FROM version');
+	$version = get_cacti_version();
 	echo "Cacti Add Tree Utility, Version $version, " . COPYRIGHT_YEARS . "\n";
 }
 
