@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -112,7 +112,7 @@ function form_save() {
 			if (($_FILES['import_file']['tmp_name'] != 'none') && ($_FILES['import_file']['tmp_name'] != '')) {
 				$csv_data = file($_FILES['import_file']['tmp_name']);
 				$debug_data = color_import_processor($csv_data);
-	
+
 				if (sizeof($debug_data)) {
 					$_SESSION['import_debug_info'] = $debug_data;
 				}
@@ -139,7 +139,7 @@ function form_actions() {
 	/* ================= input validation ================= */
 	get_filter_request_var('drp_action', FILTER_VALIDATE_REGEXP, array('options' => array('regexp' => '/^([a-zA-Z0-9_]+)$/')));
 	/* ==================================================== */
-	
+
 	/* if we are to save this form, instead of display it */
 	if (isset_request_var('selected_items')) {
 		$selected_items = sanitize_unserialize_selected_items(get_nfilter_request_var('selected_items'));
@@ -178,7 +178,7 @@ function form_actions() {
 
 	form_start('color.php');
 
-	html_start_box($color_actions{get_nfilter_request_var('drp_action')}, '60%', '', '3', 'center', '');
+	html_start_box($color_actions[get_nfilter_request_var('drp_action')], '60%', '', '3', 'center', '');
 
 	if (isset($color_array) && sizeof($color_array)) {
 		if (get_nfilter_request_var('drp_action') == '1') { /* delete */
@@ -189,11 +189,11 @@ function form_actions() {
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __n('Delete Color', 'Delete Colors', sizeof($color_array)) . "'>";
+			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __n('Delete Color', 'Delete Colors', sizeof($color_array)) . "'>";
 		}
 	} else {
 		print "<tr><td class='odd'><span class='textError'>" . __('You must select at least one Color.') . "</span></td></tr>\n";
-		$save_html = "<input type='button' value='" . __('Return') . "' onClick='cactiReturnTo()'>";
+		$save_html = "<input type='button' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
 	}
 
 	print "<tr>
@@ -226,7 +226,7 @@ function color_import_processor(&$colors) {
 			if ($i == 0) {
 				$save_order = '(';
 				$j = 0;
-				$first_column = TRUE;
+				$first_column = true;
 				$required = 0;
 				$update_suffix = '';
 
@@ -246,7 +246,7 @@ function color_import_processor(&$colors) {
 							$save_order .= $line_item;
 
 							$insert_columns[] = $j;
-							$first_column = FALSE;
+							$first_column = false;
 
 							if ($update_suffix != '') {
 								$update_suffix .= ", $line_item=VALUES($line_item)";
@@ -276,7 +276,7 @@ function color_import_processor(&$colors) {
 		} else {
 			$save_value = '(';
 			$j = 0;
-			$first_column = TRUE;
+			$first_column = true;
 			$sql_where = '';
 
 			if (sizeof($line_array)) {
@@ -288,7 +288,7 @@ function color_import_processor(&$colors) {
 					if (!$first_column) {
 						$save_value .= ',';
 					} else {
-						$first_column = FALSE;
+						$first_column = false;
 					}
 
 					$save_value .= "'" . $line_item . "'";
@@ -384,7 +384,7 @@ function color_import() {
 			<input type='checkbox' name='allow_update' id='allow_update'><?php print __('Allow Existing Rows to be Updated?');?>
 		</td><?php
 
-	html_end_box(FALSE);
+	html_end_box(false);
 
 	html_start_box( __('Required File Format Notes'), '100%', '', '3', 'center', '');
 
@@ -464,38 +464,38 @@ function process_request_vars() {
 	/* ================= input validation and session storage ================= */
 	$filters = array(
 		'rows' => array(
-			'filter' => FILTER_VALIDATE_INT, 
+			'filter' => FILTER_VALIDATE_INT,
 			'pageset' => true,
 			'default' => '-1'
 			),
 		'page' => array(
-			'filter' => FILTER_VALIDATE_INT, 
+			'filter' => FILTER_VALIDATE_INT,
 			'default' => '1'
 			),
 		'filter' => array(
-			'filter' => FILTER_CALLBACK, 
+			'filter' => FILTER_CALLBACK,
 			'pageset' => true,
-			'default' => '', 
+			'default' => '',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 		'sort_column' => array(
-			'filter' => FILTER_CALLBACK, 
-			'default' => 'name', 
+			'filter' => FILTER_CALLBACK,
+			'default' => 'name',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 		'sort_direction' => array(
-			'filter' => FILTER_CALLBACK, 
-			'default' => 'ASC', 
+			'filter' => FILTER_CALLBACK,
+			'default' => 'ASC',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 		'has_graphs' => array(
-			'filter' => FILTER_VALIDATE_REGEXP, 
+			'filter' => FILTER_VALIDATE_REGEXP,
 			'options' => array('options' => array('regexp' => '(true|false)')),
 			'pageset' => true,
 			'default' => read_config_option('default_has') == 'on' ? 'true':'false'
 			),
 		'named' => array(
-			'filter' => FILTER_VALIDATE_REGEXP, 
+			'filter' => FILTER_VALIDATE_REGEXP,
 			'options' => array('options' => array('regexp' => '(true|false)')),
 			'pageset' => true,
 			'default' => 'true'
@@ -529,7 +529,7 @@ function color() {
 						<?php print __('Search');?>
 					</td>
 					<td>
-						<input id='filter' type='text' name='filter' size='25' value='<?php print htmlspecialchars(get_request_var('filter'));?>'>
+						<input id='filter' type='text' name='filter' size='25' value='<?php print html_escape_request_var('filter');?>'>
 					</td>
 					<td>
 						<?php print __('Colors');?>
@@ -547,36 +547,39 @@ function color() {
 						</select>
 					</td>
 					<td>
-						<input type='checkbox' id='named' <?php print (get_request_var('named') == 'true' ? 'checked':'');?>>
+						<span>
+							<input type='checkbox' id='named' <?php print (get_request_var('named') == 'true' ? 'checked':'');?>>
+							<label for='named'><?php print __('Named Colors');?></label>
+						</span>
 					</td>
 					<td>
-						<label for='named'><?php print __('Named Colors');?></label>
+						<span>
+							<input type='checkbox' id='has_graphs' <?php print (get_request_var('has_graphs') == 'true' ? 'checked':'');?>>
+							<label for='has_graphs'><?php print __('Has Graphs');?></label>
+						</span>
 					</td>
 					<td>
-						<input type='checkbox' id='has_graphs' <?php print (get_request_var('has_graphs') == 'true' ? 'checked':'');?>>
+						<span>
+							<input type='button' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
+							<input type='button' id='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
+						</span>
 					</td>
 					<td>
-						<label for='has_graphs'><?php print __('Has Graphs');?></label>
-					</td>
-					<td>
-						<input type='button' id='refresh' value='<?php print __('Go');?>' title='<?php print __('Set/Refresh Filters');?>'>
-					</td>
-					<td>
-						<input type='button' id='clear' value='<?php print __('Clear');?>' title='<?php print __('Clear Filters');?>'>
-					</td>
-					<td>
-						<input type='button' id='import' value='<?php print __('Import');?>' title='<?php print __('Import Colors');?>'>
-					</td>
-					<td>
-						<input type='button' id='export' value='<?php print __('Export');?>' title='<?php print __('Export Colors');?>'>
+						<span>
+							<input type='button' id='import' value='<?php print __esc('Import');?>' title='<?php print __esc('Import Colors');?>'>
+							<input type='button' id='export' value='<?php print __esc('Export');?>' title='<?php print __esc('Export Colors');?>'>
+						</span>
 					</td>
 				</tr>
 			</table>
-			<input type='hidden' id='page' value='<?php print get_request_var('page');?>'>
 			</form>
 			<script type='text/javascript'>
 			function applyFilter() {
-				strURL = 'color.php?filter='+escape($('#filter').val())+'&rows='+$('#rows').val()+'&page='+$('#page').val()+'&has_graphs='+$('#has_graphs').is(':checked')+'&named='+$('#named').is(':checked')+'&header=false';
+				strURL  = 'color.php?header=false';
+				strURL += '&filter='+$('#filter').val();
+				strURL += '&rows='+$('#rows').val();
+				strURL += '&has_graphs='+$('#has_graphs').is(':checked');
+				strURL += '&named='+$('#named').is(':checked');
 				loadPageNoHeader(strURL);
 			}
 
@@ -626,7 +629,7 @@ function color() {
 
 	/* form the 'where' clause for our main sql query */
 	if (get_request_var('filter') != '') {
-		$sql_where = "WHERE (name LIKE '%" . get_request_var('filter') . "%' 
+		$sql_where = "WHERE (name LIKE '%" . get_request_var('filter') . "%'
 			OR hex LIKE '%" .  get_request_var('filter') . "%')";
 	} else {
 		$sql_where = '';
@@ -651,8 +654,8 @@ function color() {
 			SUM(CASE WHEN local_graph_id=0 THEN 1 ELSE 0 END) AS templates
 			FROM colors AS c
 			LEFT JOIN (
-				SELECT DISTINCT color_id, graph_template_id, local_graph_id 
-				FROM graph_templates_item 
+				SELECT DISTINCT color_id, graph_template_id, local_graph_id
+				FROM graph_templates_item
 				WHERE color_id>0
 			) AS gti
 			ON gti.color_id=c.id
@@ -671,8 +674,8 @@ function color() {
 			SELECT c.*, local_graph_id
 			FROM colors AS c
 			LEFT JOIN (
-				SELECT DISTINCT color_id, graph_template_id, local_graph_id 
-				FROM graph_templates_item 
+				SELECT DISTINCT color_id, graph_template_id, local_graph_id
+				FROM graph_templates_item
 				WHERE color_id>0
 			) AS gti
 			ON c.id=gti.color_id
@@ -748,7 +751,7 @@ function color_export() {
 
 	/* form the 'where' clause for our main sql query */
 	if (get_request_var('filter') != '') {
-		$sql_where = "WHERE (name LIKE '%" . get_request_var('filter') . "%' 
+		$sql_where = "WHERE (name LIKE '%" . get_request_var('filter') . "%'
 			OR hex LIKE '%" .  get_request_var('filter') . "%')";
 	} else {
 		$sql_where = '';
@@ -771,8 +774,8 @@ function color_export() {
 			SELECT c.*, local_graph_id
 			FROM colors AS c
 			LEFT JOIN (
-				SELECT color_id, graph_template_id, local_graph_id 
-				FROM graph_templates_item 
+				SELECT color_id, graph_template_id, local_graph_id
+				FROM graph_templates_item
 				WHERE color_id>0
 			) AS gti
 			ON c.id=gti.color_id
