@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -91,6 +91,17 @@ $cacti_version_codes = array(
 	'1.1.15' => '0101',
 	'1.1.16' => '0101',
 	'1.1.17' => '0101',
+	'1.1.18' => '0101',
+	'1.1.19' => '0101',
+	'1.1.20' => '0101',
+	'1.1.21' => '0101',
+	'1.1.22' => '0101',
+	'1.1.23' => '0101',
+	'1.1.24' => '0101',
+	'1.1.25' => '0101',
+	'1.1.26' => '0101',
+	'1.1.27' => '0101',
+	'1.1.28' => '0101',
 );
 
 $messages = array(
@@ -115,6 +126,12 @@ $messages = array(
 	7  => array(
 		'message' => __('XML parse error.'),
 		'type' => 'error'),
+	8  => array(
+		'message' => __('Form types dirpath and filepath must point to a valid diretory or file.'),
+		'type' => 'error'),
+	9  => array(
+		'message' => __('The Cacti log file must have the extension \'.log\''),
+		'type' => 'error'),
 	12 => array(
 		'message' => __('Username already in use.'),
 		'type' => 'error'),
@@ -178,6 +195,12 @@ $messages = array(
 	34 => array(
 		'message' => __('Unable to Change Device for Data Query based Graphs.'),
 		'type' => 'error'),
+	'clog_invalid' => array(
+		'message' => __('Log file specified is not a Cacti log or archive file.'),
+		'type' => 'info'),
+	'clog_remove' => array(
+		'message' => __('Log file specified was Cacti archive file and was removed.'),
+		'type' => 'info'),
 	'clog_purged' => array(
 		'message' => __('Cacti Log purged successfully'),
 		'type' => 'info'),
@@ -222,6 +245,9 @@ $messages = array(
 		'type' => 'info'),
 	'reports_item_save_failed' => array(
 		'message' => '<font style="color:red;"><i>' . __('Report Item Save Failed') . '</i></font>',
+		'type' => 'info'),
+	'resource_cache_rebuild' => array(
+		'message' => '<i>' . __('Poller Resource Cache Cleared.  Main Data Collector will rebuild at the next poller start, and Remote Data Collectors will sync afterwards.'),
 		'type' => 'info')
 );
 
@@ -318,7 +344,7 @@ $vdef_item_types = array(
 	CVDEF_ITEM_TYPE_STRING          => __('Custom String'),
 );
 
-$custom_vdef_data_source_types = array( // this may change as soon as RRDTool supports math in VDEF, until then only reference to CDEF may help
+$custom_vdef_data_source_types = array( // this may change as soon as RRDtool supports math in VDEF, until then only reference to CDEF may help
 	'CURRENT_DATA_SOURCE' => __('Current Graph Item Data Source'),
 );
 
@@ -636,11 +662,11 @@ $ldap_modes = array(
 );
 
 $rrdtool_versions = array(
-	'rrd-1.3.x' => 'RRDTool 1.3.x',
-	'rrd-1.4.x' => 'RRDTool 1.4.x',
-	'rrd-1.5.x' => 'RRDTool 1.5.x',
-	'rrd-1.6.x' => 'RRDTool 1.6.x',
-	'rrd-1.7.x' => 'RRDTool 1.7.x'
+	'rrd-1.3.x' => 'RRDtool 1.3.x',
+	'rrd-1.4.x' => 'RRDtool 1.4.x',
+	'rrd-1.5.x' => 'RRDtool 1.5.x',
+	'rrd-1.6.x' => 'RRDtool 1.6.x',
+	'rrd-1.7.x' => 'RRDtool 1.7.x'
 );
 
 $i18n_modes = array(
@@ -886,6 +912,7 @@ $page_refresh_interval = array(
 $user_auth_realms = array(
 	8    => __('Console Access'),
 	7    => __('View Graphs'),
+	25   => __('Realtime Graphs'),
 	20   => __('Update Profile'),
 	24   => __('External Links'),
 
@@ -919,7 +946,7 @@ $user_auth_realms = array(
 );
 
 $user_auth_roles = array(
-	'Normal User'            => array(7, 19, 20, 22, 24),
+	'Normal User'            => array(7, 19, 20, 22, 24, 25),
 	'Template Editor'        => array(8, 2, 9, 10, 11, 12, 13, 14, 16, 17),
 	'General Administration' => array(8, 3, 4, 5, 23, 1043),
 	'System Administration'  => array(8, 15, 1, 18, 21, 101)
@@ -944,7 +971,7 @@ $user_auth_realm_filenames = array(
 	'graph_templates_inputs.php' => 10,
 	'graph_templates_items.php' => 10,
 	'graph_view.php' => 7,
-	'graph_realtime.php' => 7,
+	'graph_realtime.php' => 25,
 	'graphs.php' => 5,
 	'graphs_items.php' => 5,
 	'graphs_new.php' => 5,
