@@ -16,7 +16,7 @@
  */
 class Twig_Environment
 {
-    const VERSION = '1.24.1-DEV';
+    const VERSION = '1.24.2';
 
     protected $charset;
     protected $loader;
@@ -438,6 +438,10 @@ class Twig_Environment
         } catch (Exception $e) {
             $this->setLoader($current);
 
+            throw $e;
+        } catch (Throwable $e) {
+            $this->setLoader($current);
+
             throw $e;
         }
         $this->setLoader($current);
