@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -97,6 +97,7 @@ $selectedTheme = get_selected_theme();
 	<div class='scrollBar'></div>
 	<?php if (read_config_option('auth_method') != 0) {?><div class='infoBar'><?php echo draw_login_status($using_guest_account);?></div><?php }?>
 </div>
+<div class='cactiShadow'></div>
 <div id='cactiContent' class='cactiContent'>
 	<?php if (isset($user_menu) && is_array($user_menu)) {?>
 	<div style='display:none;' id='navigation' class='cactiConsoleNavigationArea'>
