@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -22,7 +22,6 @@
  +-------------------------------------------------------------------------+
 */
 
-function upgrade_to_1_1_14() {
-	db_install_execute('ALTER TABLE automation_networks
-		MODIFY COLUMN subnet_range VARCHAR(1024) NOT NULL DEFAULT ""');
+function upgrade_to_0_8_2a() {
+	db_install_execute("ALTER TABLE `data_input_data_cache` ADD `rrd_num` TINYINT( 2 ) UNSIGNED NOT NULL AFTER `rrd_path`;");
 }
