@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -288,14 +288,14 @@ function api_device_save($id, $host_template_id, $description, $hostname, $snmp_
 								(chgrp($host_dir, $group_id))) {
 								/* permissions set ok */
 							} else {
-								cacti_log("ERROR: Unable to set directory permissions for '" . $host_dir . "'", FALSE);
+								cacti_log("ERROR: Unable to set directory permissions for '" . $host_dir . "'", false);
 							}
 						}
 					} else {
-						cacti_log("ERROR: Unable to create directory '" . $host_dir . "'", FALSE);
+						cacti_log("ERROR: Unable to create directory '" . $host_dir . "'", false);
 					}
 				} else {
-					cacti_log("ERROR: Unable to create directory due to missing write permissions '" . $host_dir . "'", FALSE);
+					cacti_log("ERROR: Unable to create directory due to missing write permissions '" . $host_dir . "'", false);
 				}
 			}
 		}
@@ -392,8 +392,19 @@ function api_device_ping_device($device_id, $from_remote = false) {
 	$anym = false;
 
 	if ($config['poller_id'] != $host['poller_id'] && $from_remote == false) {
-		$hostname = db_fetch_cell_prepared('SELECT hostname FROM poller WHERE id = ?', array($host['poller_id']));
-		print file_get_contents(get_url_type() .'://' . $hostname . $config['url_path'] . 'remote_agent.php?action=ping&host_id=' . $host['id']);
+		$hostname = db_fetch_cell_prepared('SELECT hostname
+			FROM poller
+			WHERE id = ?',
+			array($host['poller_id']));
+		
+		$fgc_contextoption = get_default_contextoption();
+		if($fgc_contextoption) {
+			$fgc_context = stream_context_create($fgc_contextoption);
+			print file_get_contents(get_url_type() .'://' . $hostname . $config['url_path'] . 'remote_agent.php?action=ping&host_id=' . $host['id'], false, $fgc_context);
+		} else {
+			print file_get_contents(get_url_type() .'://' . $hostname . $config['url_path'] . 'remote_agent.php?action=ping&host_id=' . $host['id']);
+		}
+
 		return;
 	}
 
