@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -36,9 +36,18 @@ function run_data_query($host_id, $snmp_query_id) {
 	$poller_id = $status['poller_id'];
 
 	if ($poller_id != $config['poller_id']) {
-		$hostname = db_fetch_cell_prepared('SELECT hostname FROM poller WHERE id = ?', array($poller_id));
+		$hostname = db_fetch_cell_prepared('SELECT hostname
+			FROM poller
+			WHERE id = ?',
+			array($poller_id));
 
-		$response = file_get_contents(get_url_type() . '://' . $hostname . $config['url_path'] . '/remote_agent.php?action=runquery&host_id=' . $host_id . '&data_query_id=' . $snmp_query_id);
+		$fgc_contextoption = get_default_contextoption();
+		if($fgc_contextoption) {
+			$fgc_context = stream_context_create($fgc_contextoption);
+			$response = file_get_contents(get_url_type() . '://' . $hostname . $config['url_path'] . '/remote_agent.php?action=runquery&host_id=' . $host_id . '&data_query_id=' . $snmp_query_id, false, $fgc_context);
+		} else {
+			$response = file_get_contents(get_url_type() . '://' . $hostname . $config['url_path'] . '/remote_agent.php?action=runquery&host_id=' . $host_id . '&data_query_id=' . $snmp_query_id);
+		}
 
 		if ($response != '') {
 			$response = json_decode($response, true);
@@ -326,7 +335,7 @@ function query_debug_timer_offset($section, $message) {
 	return $delta;
 }
 
-function query_debug_timer_stop($sction, $message) {
+function query_debug_timer_stop($section, $message) {
 	global $query_debug_timer, $query_debug_start;
 
 	/* record the start time */
@@ -380,7 +389,7 @@ function query_snmp_host($host_id, $snmp_query_id) {
 		$host['snmp_context'], $host['snmp_engine_id'],  $host['snmp_port'],
 		$host['snmp_timeout'], $host['ping_retries'], $host['max_oids']);
 
-	if ($session === FALSE) {
+	if ($session === false) {
 		debug_log_insert('data_query', 'Failed to load SNMP session.');
 
 		return false;
@@ -755,16 +764,26 @@ function data_query_format_record($host_id, $snmp_query_id, $field_name, $rewrit
 	}
 
 	$data_query_rewrite_indexes_cache[$hash][$snmp_index] = $value;
-	if (ctype_print($value) === FALSE) {
+	if (data_query_ctype_print_unicode($value) === false) {
 		$value = bin2hex($value);
 	}
 
 	return "($host_id, $snmp_query_id, " . db_qstr($field_name) . ', ' . db_qstr($value) . ', ' . db_qstr($snmp_index) . ', ' . db_qstr($oid) . ', 1)';
 }
 
+function data_query_ctype_print_unicode($value) {
+	$pattern = "~^[\pL\pN\s\"\~" . preg_quote("!#$%&'()*+,-./:;<=>?@[\]^_`{|}´") . "]+$~u";
+
+	return preg_match($pattern, $value);
+}
+
 function data_query_update_host_cache_from_buffer($host_id, $snmp_query_id, &$output_array) {
 	/* set all fields present value to 0, to mark the outliers when we are all done */
-	db_execute_prepared('UPDATE host_snmp_cache SET present=0 WHERE host_id = ? AND snmp_query_id = ?', array($host_id, $snmp_query_id));
+	db_execute_prepared('UPDATE host_snmp_cache
+		SET present=0
+		WHERE host_id = ?
+		AND snmp_query_id = ?',
+		array($host_id, $snmp_query_id));
 
 	/* setup the database call */
 	$sql_prefix   = 'INSERT INTO host_snmp_cache (host_id, snmp_query_id, field_name, field_value, snmp_index, oid, present) VALUES';
@@ -820,7 +839,7 @@ function data_query_update_host_cache_from_buffer($host_id, $snmp_query_id, &$ou
 	@returns - (array) of original snmp indexes associated with rewritten ones
 */
 
-function data_query_rewrite_indexes(&$errmsg, $host_id, $snmp_query_id, $rewrite_index, $snmp_indexes, $fields_processed = FALSE){
+function data_query_rewrite_indexes(&$errmsg, $host_id, $snmp_query_id, $rewrite_index, $snmp_indexes, $fields_processed = false){
 	global $data_query_rewrite_indexes_cache;
 
 	$errmsg = array();
@@ -831,47 +850,47 @@ function data_query_rewrite_indexes(&$errmsg, $host_id, $snmp_query_id, $rewrite
 		$data_query_rewrite_indexes_cache = array();
 
 	if (sizeof($oid_items)){
-	foreach($oid_items as $item){
-		$matches = array();
-		if (preg_match('/^\|query_([^|]+)\|$/', $item, $matches)){
-			$iv = $matches[1];
-			if (is_array($fields_processed) && !in_array($iv, $fields_processed)){
-				$errmsg[] = "rewrite_index='$rewrite_index': '$iv' is not processed yet, could not use it as index source";
-					continue;
-			}
+		foreach($oid_items as $item){
+			$matches = array();
+			if (preg_match('/^\|query_([^|]+)\|$/', $item, $matches)){
+				$iv = $matches[1];
+				if (is_array($fields_processed) && !in_array($iv, $fields_processed)){
+					$errmsg[] = "rewrite_index='$rewrite_index': '$iv' is not processed yet, could not use it as index source";
+						continue;
+				}
 
-			if (!isset($chain_indexes[$iv])) {
-				$hash =  "$host_id@$snmp_query_id@$iv";
-				if (!isset($data_query_rewrite_indexes_cache[$hash])) {
-					$data_query_rewrite_indexes_cache[$hash] = array();
-					$iv = db_qstr($iv);
+				if (!isset($chain_indexes[$iv])) {
+					$hash =  "$host_id@$snmp_query_id@$iv";
+					if (!isset($data_query_rewrite_indexes_cache[$hash])) {
+						$data_query_rewrite_indexes_cache[$hash] = array();
+						$iv = db_qstr($iv);
 
-					$field_values = db_fetch_assoc_prepared("SELECT snmp_index, field_value
-						FROM host_snmp_cache
-						WHERE host_id = ?
-						AND snmp_query_id = ?
-						AND field_name = ?",
-						array($host_id, $snmp_query_id, $iv));
+						$field_values = db_fetch_assoc_prepared("SELECT snmp_index, field_value
+							FROM host_snmp_cache
+							WHERE host_id = ?
+							AND snmp_query_id = ?
+							AND field_name = ?",
+							array($host_id, $snmp_query_id, $iv));
 
-					if (sizeof($field_values)){
-						foreach($field_values as $item){
-							$data_query_rewrite_indexes_cache[$hash][$item['snmp_index']] = $item['field_value'];
+						if (sizeof($field_values)){
+							foreach($field_values as $item){
+								$data_query_rewrite_indexes_cache[$hash][$item['snmp_index']] = $item['field_value'];
+							}
+						} else {
+							$errmsg[] = " field '$iv' was not found either in cache nor in DB";
 						}
-					} else {
-						$errmsg[] = " field '$iv' was not found either in cache nor in DB";
 					}
+					$chain_indexes[$iv] = $data_query_rewrite_indexes_cache[$hash];
 				}
-				$chain_indexes[$iv] = $data_query_rewrite_indexes_cache[$hash];
 			}
 		}
 	}
-	}
 
 	$out = array();
-	$numeric_output = FALSE;
+	$numeric_output = false;
 	if (!is_array($snmp_indexes)){
 		$snmp_indexes = array($snmp_indexes);
-		$numeric_output = TRUE;
+		$numeric_output = true;
 	}
 	foreach ($snmp_indexes as $oid => $num_index) {
 		$index = $rewrite_index;
@@ -929,7 +948,7 @@ function rewrite_snmp_enum_value($field_name, $value=NULL, $map=NULL){
 		$map = unserialize($map);
 	}
 
-	if ($map === FALSE || !is_array($map)){
+	if ($map === false || !is_array($map)){
 		debug_log_insert('data_query', 'Could not parse translation map (rewrite_value)');
 		return $value;
 	}
