@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -181,7 +181,7 @@ function nth_percentile($local_data_id, $start_seconds, $end_seconds, $percentil
 					$return_array['nth_percentile_aggregate_total'] = $values_array[$target];
 				}
 			} else {
-				$return_array{'nth_percentile_aggregate_total'} = $values_array[$target];
+				$return_array['nth_percentile_aggregate_total'] = $values_array[$target];
 			}
 		}
 	}
