@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -155,22 +155,24 @@ function form_alternate_row($row_id = '', $light = false, $disabled = false) {
    @arg $width - the width of the table element
    @arg $style_or_class - the style or class to apply to the table element
    @arg $title - optional title for the column */
-function form_selectable_cell($contents, $id, $width='', $style_or_class = '', $title = '') {
+function form_selectable_cell($contents, $id, $width = '', $style_or_class = '', $title = '') {
 	$output = '';
 
 	if ($style_or_class != '') {
 		if (strpos($style_or_class, ':') === false) {
-			$output = "class='" . $style_or_class . "'";
+			$output = "class='nowrap " . $style_or_class . "'";
 			if ($width != '') {
 				$output .= " style='width:$width;'";
 			}
 		} else {
-			$output = "style='" . $style_or_class;
+			$output = "class='nowrap' style='" . $style_or_class;
 			if ($width != '') {
-				$output .= ($output != '' ? ';':'') . "width:$width;";
+				$output .= ";width:$width;";
 			}
 			$output .= "'";
 		}
+	} else {
+		$output = 'class="nowrap"';
 	}
 
 	if ($title != '') {
@@ -381,7 +383,7 @@ function get_filter_request_var($name, $filter = FILTER_VALIDATE_INT, $options =
 				if ($valid === true) {
 					$value = $_REQUEST[$name];
 				} else {
-					$value = FALSE;
+					$value = false;
 					$custom_error = $valid;
 				}
 			} elseif ($filter == FILTER_VALIDATE_IS_NUMERIC_ARRAY) {
@@ -426,7 +428,7 @@ function get_filter_request_var($name, $filter = FILTER_VALIDATE_INT, $options =
 
 		if ($value === false) {
 			if ($filter == FILTER_VALIDATE_IS_REGEX) {
-				$_SESSION['custom_error'] = __('The search term "%s" is not valid. Error is %s', get_nfilter_request_var($name), $cusom_error);
+				$_SESSION['custom_error'] = __('The search term "%s" is not valid. Error is %s', get_nfilter_request_var($name), $custom_error);
 				set_request_var($name, '');
 				raise_message('custom_error');
 			} else {
@@ -743,8 +745,8 @@ function get_order_string() {
 function remove_column_from_order_string($column) {
 	$page = get_order_string_page();
 
-	if (isset($_SESSIION['sort_data'][$page][$column])) {
-		unset($_SESSIION['sort_data'][$page][$column]);
+	if (isset($_SESSION['sort_data'][$page][$column])) {
+		unset($_SESSION['sort_data'][$page][$column]);
 		update_order_string(true);
 	}
 }
