@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -161,21 +161,23 @@ class Ldap {
 		$this->version    = read_config_option('ldap_version');
 		$this->encryption = read_config_option('ldap_encryption');
 		$this->referrals  = read_config_option('ldap_referrals');
+
 		if (read_config_option('ldap_group_require') == 'on') {
 			$this->group_require = true;
 		} else {
 			$this->group_require = false;
 		}
+
 		$this->group_dn          = read_config_option('ldap_group_dn');
 		$this->group_attrib      = read_config_option('ldap_group_attrib');
 		$this->group_member_type = read_config_option('ldap_group_member_type');
 
 		/* Initialize LDAP parameters for Search */
 		$this->mode              = read_config_option('ldap_mode');
-		$this->specific_dn       = read_config_option('ldap_specific_dn');
-		$this->specific_password = read_config_option('ldap_specific_password');
 		$this->search_base       = read_config_option('ldap_search_base');
 		$this->search_filter     = read_config_option('ldap_search_filter');
+		$this->specific_dn       = read_config_option('ldap_specific_dn');
+		$this->specific_password = read_config_option('ldap_specific_password');
 
 		return true;
 	}
@@ -185,7 +187,23 @@ class Ldap {
 	}
 
 	function ErrorHandler($level, $message, $file, $line, $context) {
-		return false;
+		return true;
+	}
+
+	function SetLdapHandler() {
+		/* drop out of cactis error handler */
+		restore_error_handler();
+
+		/* set an error handler for ldap */
+		set_error_handler(array($this, 'ErrorHandler'));
+	}
+
+	function RestoreCactiHandler() {
+		/* drop out of ldaps error handler */
+		restore_error_handler();
+
+		/* set an error handler for Cacti */
+		set_error_handler('CactiErrorHandler');
 	}
 
 	function Authenticate() {
@@ -212,8 +230,7 @@ class Ldap {
 		$this->username = html_entity_decode($this->username, $this->GetMask(), 'UTF-8');
 		$this->password = html_entity_decode($this->password, $this->GetMask(), 'UTF-8');
 
-		/* set an error handler for ldap */
-		set_error_handler(array($this, 'ErrorHandler'));
+		$this->SetLdapHandler();
 
 		/* Determine connection method and create LDAP Object */
 		if ($this->encryption == '1') {
@@ -232,7 +249,7 @@ class Ldap {
 				$output['error_text'] = __('Protocol Error, Unable to set version');
 				cacti_log('LDAP: ' . $output['error_text'], false, 'AUTH');
 				ldap_close($ldap_conn);
-				restore_error_handler();
+				$this->RestoreCactiHandler();
 				return $output;
 			}
 
@@ -243,7 +260,7 @@ class Ldap {
 					$output['error_text'] = __('Unable to set referrals option');
 					cacti_log('LDAP: ' . $output['error_text'], false, 'AUTH');
 					ldap_close($ldap_conn);
-					restore_error_handler();
+					$this->RestoreCactiHandler();
 					return $output;
 				}
 			}
@@ -255,7 +272,7 @@ class Ldap {
 					$output['error_text'] = __('Protocol Error, unable to start TLS communications');
 					cacti_log('LDAP: ' . $output['error_text'], false, 'AUTH');
 					ldap_close($ldap_conn);
-					restore_error_handler();
+					$this->RestoreCactiHandler();
 					return $output;
 				}
 			}
@@ -297,14 +314,14 @@ class Ldap {
 						$output['error_text'] = __('Insufficient access');
 						cacti_log('LDAP: ' . $output['error_text'], false, 'AUTH');
 						ldap_close($ldap_conn);
-						restore_error_handler();
+						$this->RestoreCactiHandler();
 						return $output;
 					} else {
 						$output['error_num'] = '12';
 						$output['error_text'] = __('Group DN could not be found to compare');
 						cacti_log('LDAP: ' . $output['error_text'], false, 'AUTH');
 						ldap_close($ldap_conn);
-						restore_error_handler();
+						$this->RestoreCactiHandler();
 						return $output;
 					}
 				} else {
@@ -354,7 +371,7 @@ class Ldap {
 			cacti_log('LDAP: ' . $output['error_text'], false, 'AUTH');
 		}
 
-		restore_error_handler();
+		$this->RestoreCactiHandler();
 
 		return $output;
 	}
@@ -477,7 +494,7 @@ class Ldap {
 						$output['dn'] = $ldap_entries['0']['dn'];
 						$output['error_num'] = '0';
 						$output['error_text'] = __('User found');
-						cacti_log("LDAP_SEARCH: User found, DN '%s'" . $output['dn'], false, 'AUTH');
+						cacti_log('LDAP_SEARCH: ' . $output['error_text'] . ', DN \'' . $output['dn'] . '\'', false, 'AUTH');
 					} elseif ($ldap_entries['count'] > 1) {
 						/* more than 1 result */
 						$output['dn'] = '';
