@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -38,7 +38,7 @@ function get_vdef_item_name($vdef_item_id) 	{
 	}
 }
 
-/* get_vdef - resolves an entire VDEF into its text-based representation for use in the RRDTool 'graph'
+/* get_vdef - resolves an entire VDEF into its text-based representation for use in the RRDtool 'graph'
      string. this name will be resolved recursively if necessary
    @param $vdef_id - the id of the vdef to resolve
    @returns - a text-based representation of the vdef */
