@@ -14,7 +14,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -376,8 +376,10 @@ while ($poller_runs_completed < $poller_runs) {
 
 		if (sizeof($issues)) {
 			$issue_list =  'DS[';
+			$i = 0;
 			foreach($issues as $issue) {
-				$issue_list .= ($issue_list != '' ? ', ' : '') . $issue['local_data_id'];
+				$issue_list .= ($i > 0 ? ', ' : '') . $issue['local_data_id'];
+				$i++;
 			}
 			$issue_list .= ']';
 		}
@@ -485,7 +487,7 @@ while ($poller_runs_completed < $poller_runs) {
 		if ($host_count > 1) {
 			$last_host = $item['id'];
 
-			exec_background($command_string, "$extra_args --poller=$poller_id --first=$first_host --last=$last_host");
+			exec_background($command_string, "$extra_args --poller=$poller_id --first=$first_host --last=$last_host" . ($mibs ? ' --mibs':''));
 			usleep(100000);
 
 			$started_processes++;
