@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -44,6 +44,9 @@ set_default_action();
 
 switch (get_request_var('action')) {
 	case 'polldata':
+		// Only let realtime polling run for a short time
+		ini_set('max_execution_time', read_config_option('script_timeout'));
+
 		debug('Start: Poling Data for Realtime');
 		poll_for_data();
 		debug('End: Poling Data for Realtime');
@@ -129,6 +132,11 @@ function remote_client_authorized() {
 		return false;
 	}
 
+	if (!filter_var($client_addr, FILTER_VALIDATE_IP)) {
+		cacti_log('ERROR: Invalid remote agent client IP Address.  Exiting');
+		return false;
+	}
+
 	$client_name = strip_domain(gethostbyaddr($client_addr));
 
 	$pollers = db_fetch_assoc('SELECT * FROM poller');
@@ -186,7 +194,7 @@ function get_graph_data() {
 		$graph_data_array['graph_nolegend'] = get_request_var('graph_nolegend');
 	}
 
-	/* print RRDTool graph source? */
+	/* print RRDtool graph source? */
 	if (!isempty_request_var('show_source')) {
 		$graph_data_array['print_source'] = get_request_var('show_source');
 	}
@@ -277,17 +285,17 @@ function poll_for_data() {
 	$host_id       = get_filter_request_var('host_id');
 	$poller_id     = get_nfilter_request_var('poller_id');
 
-	$item = db_fetch_row_prepared('SELECT * 
-		FROM poller_item 
-		WHERE host_id = ? 
-		AND local_data_id = ?', 
+	$item = db_fetch_row_prepared('SELECT *
+		FROM poller_item
+		WHERE host_id = ?
+		AND local_data_id = ?',
 		array($host_id, $local_data_id));
 
-	$script_server_calls = db_fetch_cell_prepared('SELECT COUNT(*) 
-		FROM poller_item 
-		WHERE host_id = ? 
-		AND local_data_id = ? 
-		AND action = 2', 
+	$script_server_calls = db_fetch_cell_prepared('SELECT COUNT(*)
+		FROM poller_item
+		WHERE host_id = ?
+		AND local_data_id = ?
+		AND action = 2',
 		array($host_id, $local_data_id));
 
 	if (sizeof($item)) {
