@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -172,7 +172,7 @@ switch (get_request_var('action')) {
 			FROM mysql.time_zone_name
 			WHERE Name LIKE ?
 			ORDER BY Name
-			LIMIT ' . read_config_options('autocomplete_rows'),
+			LIMIT ' . read_config_option('autocomplete_rows'),
 			array('%' . get_nfilter_request_var('term') . '%')));
 
 		break;
@@ -277,7 +277,7 @@ function form_actions() {
 
 	form_start('sites.php');
 
-	html_start_box($site_actions{get_nfilter_request_var('drp_action')}, '60%', '', '3', 'center', '');
+	html_start_box($site_actions[get_nfilter_request_var('drp_action')], '60%', '', '3', 'center', '');
 
 	if (isset($site_array) && sizeof($site_array)) {
 		if (get_nfilter_request_var('drp_action') == '1') { /* delete */
